import setuptools


setuptools.setup(
    name="GPTConnect",
    version="0.1.2",
    author="SleepyStew",
    description="A python package to make GPT functions easy",
    packages=["gptconnect"],
)
